@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ ConfigurePluginsWidget::~ConfigurePluginsWidget()
 void ConfigurePluginsWidget::initLayout(ConfigurePluginsListWidget *configurePluginListWidget)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     KMessageWidget *messageWidget = new KMessageWidget(this);
     messageWidget->setObjectName(QStringLiteral("messagewidget"));
